Rotating builders: s/reef/pyro and s/squawks/swanky/

Kernel team has rolled clang based kernel on kevin/pyro/swanky boards.
We should update rotating builders to match this and catch any kernel
related issues in llvm-next testing.

CQ-DEPEND=CL:692633
BUG=chromium:770267
TEST=jobs are launched.

Change-Id: If9f713193ec25cd0e13d7df369f09733e66ef247
Reviewed-on: https://chromium-review.googlesource.com/693135
Commit-Ready: Manoj Gupta <manojgupta@chromium.org>
Tested-by: Manoj Gupta <manojgupta@chromium.org>
Reviewed-by: Caroline Tice <cmtice@chromium.org>
diff --git a/buildbot_test_llvm.py b/buildbot_test_llvm.py
index dd88b5b..0cc61e5 100755
--- a/buildbot_test_llvm.py
+++ b/buildbot_test_llvm.py
@@ -50,9 +50,9 @@
 #  nyan_big   armv7    nyan       tegra         3.10.18
 #  peach_pit  armv7    peach      exynos-5420   3.8.11
 #  peppy      x86_64   slippy     haswell       3.8.11
 #  reef       x86_64   reef       apollo lake   4.4.79
 #  sentry     x86_64   kunimitsu  skylake-u     3.18
 #  squawks    x86_64   rambi      baytrail      4.4.79
 #  terra      x86_64   strago     braswell      3.18
 #  whirlwind  armv7                             3.14
 
@@ -68,9 +68,9 @@
     'nyan_big',
     'peach_pit',
     'peppy',
-    'reef',
+    'pyro',
     'sentry',
-    'squawks',
+    'swanky',
     'terra',
     'whirlwind',
 ]
@@ -50,9 +50,9 @@
 #  peach_pit  armv7    peach      exynos-5420   3.8.11
 #  peppy      x86_64   slippy     haswell       3.8.11
-#  reef       x86_64   reef       apollo lake   4.4.79
+#  pyro       x86_64   reef       apollo lake   4.4.79
 #  sentry     x86_64   kunimitsu  skylake-u     3.18
@@ -50,9 +50,9 @@
 #  sentry     x86_64   kunimitsu  skylake-u     3.18
-#  squawks    x86_64   rambi      baytrail      4.4.79
+#  swanky     x86_64   rambi      baytrail      4.4.79
 #  terra      x86_64   strago     braswell      3.18
 #  whirlwind  armv7                             3.14